@@ -300,7 +300,10 @@ def main(argv=sys.argv[1:], loop=None):
     proxy = RFLinkProxy(port=port, host=host, baud=baud, loop=loop)
 
     server_coro = asyncio.start_server(
-        proxy.client_connected_callback, host="", port=listenport, loop=loop,
+        proxy.client_connected_callback,
+        host="",
+        port=listenport,
+        loop=loop,
     )
 
     server = loop.run_until_complete(server_coro)
